@@ -24,22 +24,25 @@
  ****************************************************/
 
 
-#ifndef PATIENCE_CARD
-#define PATIENCE_CARD
+#ifndef CARD_H
+#define CARD_H
 
-#include <QList>
-#include <QGraphicsScene>
-#include <QTimer>
-#include <QGraphicsSvgItem>
-
-// The following classes are defined in other headers:
 class Pile;
 class Card;
+
+#include <QtCore/QList>
+#include <QtCore/QTimer>
 class QGraphicsItemAnimation;
+#include <QtGui/QGraphicsPixmapItem>
+class QGraphicsScene;
+class QGraphicsSceneHoverEvent;
+class QGraphicsSceneMouseEvent;
+
 
 // A list of cards.  Used in many places.
 typedef QList<Card*> CardList;
 
+
 // In kpat, a Card is an object that has at least two purposes:
 //  - It has card properties (Suit, Rank, etc)
 //  - It is a graphic entity on a QCanvas that can be moved around.
@@ -82,7 +85,8 @@ public:
     Pile        *source() const     { return m_source; }
     void         setSource(Pile *p) { m_source = p; }
 
-    virtual int  type() const       { return UserType + my_type; }
+    enum { Type = UserType + 1 };
+    virtual int type() const { return Type; }
 
     void         moveTo( qreal x2, qreal y2, qreal z, int duration);
     void         flipTo( qreal x, qreal y, int duration );
@@ -126,7 +130,7 @@ public:
     void setIsSeen( VisibleState is );
 
 signals:
-    void         stoped(Card *c);
+    void       stopped(Card *c);
 
 public slots:
     void       setPixmap();
@@ -157,7 +161,6 @@ private:
     // The maximum Z ever used.
     static qreal  Hz;
 
-    static const int my_type;
     QGraphicsItemAnimation *animation;
     QGraphicsPixmapItem *m_shadow;
 
