@@ -1,11 +1,9 @@
-
-#ifndef _FORTYEIGHT_H
-#define _FORTYEIGHT_H
-
-
-#include "patsolve.h"
+#ifndef FORTYEIGHTSOLVER_H
+#define FORTYEIGHTSOLVER_H
 
 class Fortyeight;
+#include "patsolve.h"
+
 
 class FortyeightSolver : public Solver
 {
@@ -29,5 +27,5 @@ public:
     bool lastdeal;
     int freestores;
 };
-#endif
 
+#endif // FORTYEIGHTSOLVER_H
