@@ -20,22 +20,25 @@
  *
  */
 
-#ifndef __PWIDGET__H__
-#define __PWIDGET__H__
+#ifndef PWIDGET_H
+#define PWIDGET_H
 
-#include <kxmlguiwindow.h>
-//Added by qt3to4:
-#include <QPixmap>
-#include <QLabel>
-#include <QShowEvent>
-#include <krecentfilesaction.h>
-class PatienceView;
-class KToggleAction;
-class KSelectAction;
-class KRecentFilesAction;
-class QAction;
-class QLabel;
 class cardMap;
+class DealerInfo;
+class DealerScene;
+class DemoBubbles;
+class PatienceView;
+
+class KAction;
+class KRecentFilesAction;
+class KSelectAction;
+class KToggleAction;
+#include <KUrl>
+#include <KXmlGuiWindow>
+
+class QLabel;
+class QStackedWidget;
+
 
 class pWidget: public KXmlGuiWindow {
     Q_OBJECT
@@ -46,49 +49,80 @@ public:
 
 public slots:
     void undoMove();
-    void newGameType();
-    void slotNewGameType();
+    void redoMove();
+    void newGameType(int id);
+    void startRandom();
     void restart();
+    void slotShowGameSelectionScreen();
 
     void openGame();
-    void openGame(const KUrl &url);
+    bool openGame(const KUrl &url, bool addToRecentFiles = true);
     void saveGame();
 
     void newGame();
     void chooseGame();
-    void undoPossible(bool poss);
-    void gameLost();
-    void slotGameInfo(const QString &);
-    void slotUpdateMoves();
     void helpGame();
-    void enableAutoDrop();
+    void enableAutoDrop(bool enable);
+    void enableSolver(bool enable);
+    void enableRememberState(bool enable);
+    void toggleDemoAction(bool active);
     void showStats();
 
+    void slotGameSolverReset();
     void slotGameSolverStart();
     void slotGameSolverWon();
     void slotGameSolverLost();
     void slotGameSolverUnknown();
+    void slotGameLost();
+    void slotUpdateMoves(int moves);
+
     void slotPickRandom();
     void slotSelectDeck();
 
+    void slotSnapshot();
+
+    void slotGameSelected(int id);
+
+protected:
+    virtual void closeEvent(QCloseEvent * e);
+    virtual void saveNewToolbarConfig();
+
+private slots:
+    void slotSnapshot2();
+
 private:
     void setGameCaption();
-    virtual void showEvent(QShowEvent *e);
+    void startNew(int gameNumber);
+    void updateActions();
+    void updateGameActionList();
 
-private:
     // Members
-
-    PatienceView   *dill;
-
-    KSelectAction  *games;
-    QAction        *undo;
-    KToggleAction  *dropaction;
-    QAction        *stats;
-
-    QPixmap         background;
+    KAction        *undo;
+    KAction        *redo;
+    KAction        *demoaction;
+    KAction        *hintaction;
+    KAction        *drawaction;
+    KAction        *dealaction;
+    KAction        *redealaction;
+    KAction        *dropaction;
+    KAction        *gamehelpaction;
+    KToggleAction  *autodropaction;
+    KToggleAction  *solveraction;
+    KToggleAction  *rememberstateaction;
     KRecentFilesAction  *recent;
+
     cardMap        *m_cards; // possibly move to PatienceView
-    QMap<int, int>  m_dealer_map;
+    QMap<int, const DealerInfo*>  m_dealer_map;
+    QMap<int, const DealerInfo*>::const_iterator  m_dealer_it;
+    int m_freeCellId;
+
+    QStackedWidget *m_stack;
+    PatienceView   *dill;
+    DealerScene    *m_dealer;
+    DemoBubbles    *m_bubbles;
+
+    QLabel         *solverStatus;
+    QLabel         *moveStatus;
 };
 
 #endif
