@@ -19,21 +19,22 @@
 ---------------------------------------------------------------------------*/
 
 #include "spider.h"
+
+#include "deck.h"
+#include "speeds.h"
 #include "version.h"
 #include "view.h"
-#include "speeds.h"
-#include "deck.h"
 #include "patsolve/spider.h"
 
-#include <QApplication>
+#include <KActionCollection>
+#include <KConfigGroup>
+#include <KDebug>
+#include <KLocale>
+#include <KRandom>
+#include <KSelectAction>
+#include <KXMLGUIFactory>
+#include <KXmlGuiWindow>
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <kselectaction.h>
-#include <kxmlguiwindow.h>
-#include <kactioncollection.h>
-#include <kxmlguifactory.h>
-#include <kconfiggroup.h>
 
 void SpiderPile::moveCards(CardList &c, Pile *to)
 {
@@ -65,9 +66,9 @@ Spider::Spider()
     const qreal dist_x = 11.2;
 
     KConfigGroup cg(KGlobal::config(), settings_group );
-    int suits = cg.readEntry( "SpiderSuits", 2);
+    m_suits = cg.readEntry( "SpiderSuits", 2);
 
-    Deck::create_deck(this, 2, suits);
+    Deck::create_deck(this, 2, m_suits);
 
     // I deal the cards into 'redeal' piles, so hide the deck
     Deck::deck()->setVisible(false);
@@ -81,8 +82,9 @@ Spider::Spider()
         redeals[column]->setCheckIndex(0);
         redeals[column]->setAddFlags(Pile::disallow);
         redeals[column]->setRemoveFlags(Pile::disallow);
+        redeals[column]->setGraphicVisible( false );
         redeals[column]->setObjectName( QString( "redeals%1" ).arg( column ) );
-        connect(redeals[column], SIGNAL(clicked(Card*)), SLOT(deckClicked(Card*)));
+        connect(redeals[column], SIGNAL(clicked(Card*)), SLOT(newCards()));
     }
     redeals[0]->setReservedSpace( QSizeF( -50, 10 ) );
 
@@ -109,7 +111,7 @@ Spider::Spider()
         legs[column]->setAddFlags(Pile::disallow);
         legs[column]->setRemoveFlags(Pile::disallow);
         legs[column]->setTarget(true);
-        legs[column]->setVisible( false );
+        legs[column]->setGraphicVisible( false );
         legs[column]->setZValue(14 * column);
         legs[column]->setObjectName( QString( "legs%1" ).arg( column ) );
     }
@@ -118,36 +120,32 @@ Spider::Spider()
     // user should have no choice.  Also, it must be moved A first, ...
     // up to K so the King will be on top.
     setAutoDropEnabled(false);
-    setActions(DealerScene::Hint | DealerScene::Demo );
+    setActions(DealerScene::Hint | DealerScene::Demo | DealerScene::Deal);
     setSolver( new SpiderSolver( this ) );
 
-    options = new KSelectAction(i18n("Options"), this );
-    KXmlGuiWindow *xmlgui = 0;
-
-    if ( PatienceView::instance() )
-    {
-        xmlgui = PatienceView::instance()->parent();
-
-        xmlgui->actionCollection()->addAction("dealer_options", options);
-    }
-
-    options->addAction( "1 Suit (Easy)" );
-    options->addAction( "2 Suits (Medium)" );
-    options->addAction( "4 Suits (Hard)" );
-
-    if ( suits == 1 )
+    options = new KSelectAction(i18n("Spider &Options"), this );
+    options->addAction( i18n("1 Suit (Easy)") );
+    options->addAction( i18n("2 Suits (Medium)") );
+    options->addAction( i18n("4 Suits (Hard)") );
+    if ( m_suits == 1 )
         options->setCurrentItem( 0 );
-    else if ( suits == 2 )
+    else if ( m_suits == 2 )
         options->setCurrentItem( 1 );
     else
         options->setCurrentItem( 2 );
+    connect( options, SIGNAL(triggered(int)), SLOT(gameTypeChanged()) );
 
-    QList<QAction*> actionlist;
-    actionlist.append( options );
-
-    if ( xmlgui )
-        xmlgui->guiFactory()->plugActionList( xmlgui, QString::fromLatin1("dealer_options"), actionlist);
-    connect( options, SIGNAL( triggered( int ) ), SLOT( gameTypeChanged() ) );
+    if ( PatienceView::instance() )
+    {
+        KXmlGuiWindow * xmlgui = PatienceView::instance()->mainWindow();
+        if ( xmlgui )
+        {
+            xmlgui->actionCollection()->addAction("dealer_options", options);
+            QList<QAction*> actionlist;
+            actionlist.append( options );
+            xmlgui->guiFactory()->plugActionList( xmlgui, "dealer_options", actionlist);
+        }
+    }
 }
 
 void Spider::gameTypeChanged()
@@ -161,48 +159,61 @@ void Spider::gameTypeChanged()
     if ( demoActive() || isGameWon()  )
         return;
 
-    int suits = 4;
-    if ( options->currentItem() == 0 )
-        suits = 1;
-    if ( options->currentItem() == 1 )
-        suits = 2;
-
-    setSuits( suits );
+    if ( allowedToStartNewGame() )
+    {
+        if ( options->currentItem() == 0 )
+            setSuits( 1 );
+        else if ( options->currentItem() == 1 )
+            setSuits( 2 );
+        else
+            setSuits( 4 );
+        startNew(KRandom::random());
+    }
+    else
+    {
+        // If we're not allowed, reset the option to
+        // the current number of suits.
+        if ( m_suits == 1 )
+            options->setCurrentItem( 0 );
+        else if ( m_suits == 2 )
+            options->setCurrentItem( 1 );
+        else
+            options->setCurrentItem( 2 );
+    }
 }
 
 void Spider::setSuits(int suits)
 {
-    stopDemo();
-    unmarkAll();
-    Deck::destroy_deck();
-    Deck::create_deck(this, 2, suits);
-    KConfigGroup cg(KGlobal::config(), settings_group );
-    cg.writeEntry( "SpiderSuits", suits);
-    cg.sync();
-
-    switch ( suits )
+    if ( suits != m_suits )
     {
-    case 1:
-        options->setCurrentItem( 0 );
-        break;
-    case 2:
-        options->setCurrentItem( 1 );
-        break;
-    case 3:
-        options->setCurrentItem( 2 );
-        break;
+        m_suits = suits;
+
+        stopDemo();
+        unmarkAll();
+        Deck::destroy_deck();
+        Deck::create_deck(this, 2, m_suits);
+        Deck::deck()->setVisible(false);
+        KConfigGroup cg(KGlobal::config(), settings_group );
+        cg.writeEntry( "SpiderSuits", m_suits);
+        cg.sync();
+
+        if ( m_suits == 1 )
+            options->setCurrentItem( 0 );
+        else if ( m_suits == 2 )
+            options->setCurrentItem( 1 );
+        else
+            options->setCurrentItem( 2 );
     }
-    startNew();
 }
 
-void Spider::cardStoped(Card * t)
+void Spider::cardStopped(Card * t)
 {
     for( int column = 0; column < 10; column++ ) {
         Card *t = stack[column]->top();
         if (t && !t->isFaceUp())
            t->flipTo(t->x(), t->y(), DURATION_FLIP );
     }
-    t->disconnect(this, SLOT( cardStoped( Card* ) ) );
+    t->disconnect(this, SLOT( cardStopped( Card* ) ) );
     setWaiting( false );
 }
 
@@ -236,7 +247,7 @@ bool Spider::checkRemove(int /*checkIndex*/, const Pile *p, const Card *c) const
 
 //-------------------------------------------------------------------------//
 
-QString Spider::getGameState() const
+QString Spider::getGameState()
 {
     return QString::number(m_leg*10 + m_redeal);
 }
@@ -245,13 +256,7 @@ void Spider::setGameState(const QString &stream)
 {
     int i = stream.toInt();
 
-    if (m_leg > i/10) {
-        for (m_leg--; m_leg > i/10; m_leg--)
-            legs[m_leg]->setVisible(false);
-        legs[m_leg]->setVisible(false);
-    } else
-        for (; m_leg < i/10; m_leg++)
-            legs[m_leg]->setVisible(true);
+    m_leg = i/10;
 
     if (m_redeal > i%10) {
         for (m_redeal--; m_redeal > i%10; m_redeal--)
@@ -260,7 +265,18 @@ void Spider::setGameState(const QString &stream)
     } else
         for (; m_redeal < i%10; m_redeal++)
             redeals[m_redeal]->setVisible(false);
-    kDebug(11111) << m_leg << m_redeal;
+
+    emit newCardsPossible(m_redeal <= 4);
+}
+
+QString Spider::getGameOptions() const
+{
+    return QString::number(Deck::deck()->suitsNum());
+}
+
+void Spider::setGameOptions(const QString& options)
+{
+    setSuits(options.toInt());
 }
 
 //-------------------------------------------------------------------------//
@@ -269,6 +285,7 @@ void Spider::restart()
 {
     Deck::deck()->collectAndShuffle();
     deal();
+    emit newCardsPossible(true);
 }
 
 //-------------------------------------------------------------------------//
@@ -311,8 +328,6 @@ bool Spider::checkPileDeck(Pile *check, bool checkForDemo)
         // just using the CardList to see if this goes to King
         CardList run = getRun(check->top());
         if (run.first()->rank() == Card::King) {
-            legs[m_leg]->setVisible(true);
-
             CardList::iterator it = run.end();
             qreal z = 1;
             while (it != run.begin()) {
@@ -322,7 +337,7 @@ bool Spider::checkPileDeck(Pile *check, bool checkForDemo)
                 ( *it )->moveTo( legs[m_leg]->x(), legs[m_leg]->y(), legs[m_leg]->zValue() + z, 300 + int( z ) * 30 );
                 z += 1;
             }
-            connect( run.first(), SIGNAL(stoped(Card*)), SLOT(cardStoped(Card*)));
+            connect(run.first(), SIGNAL(stopped(Card*)), SLOT(cardStopped(Card*)));
             setWaiting( true );
             /*if ( demoActive() )
               newDemoMove( run.first() );*/
@@ -334,22 +349,6 @@ bool Spider::checkPileDeck(Pile *check, bool checkForDemo)
     return false;
 }
 
-void Spider::dealRow()
-{
-    if (m_redeal > 4)
-        return;
-
-    for (int column = 0; column < 10; column++) {
-        stack[column]->add(redeals[m_redeal]->top(), false);
-
-        // I may put an Ace on a K->2 pile so it could need cleared.
-        if (stack[column]->top()->rank() == Card::Ace)
-            checkPileDeck(stack[column]);
-    }
-
-    redeals[m_redeal++]->setVisible(false);
-}
-
 //-------------------------------------------------------------------------//
 
 void Spider::deal()
@@ -375,44 +374,49 @@ void Spider::deal()
         for (int i = 0; i < 10; i++ )
             redeals[column]->add(Deck::deck()->nextCard(), true);
 
-    // make the leg piles invisible
-    for (int i = 0; i < 8; i++ )
-        legs[i]->setVisible(false);
     // make the redeal piles visible
     for (int i = 0; i < 5; i++ )
         redeals[i]->setVisible(true);
 }
 
-Card *Spider::demoNewCards()
+Card *Spider::newCards()
 {
-    for ( int i = 0; i < 10; i++ )
+    if ( demoActive() )
     {
-        if ( checkPileDeck( stack[i], false ) )
-            return legs[m_leg-1]->top();
+        for ( int i = 0; i < 10; i++ )
+        {
+            if ( checkPileDeck( stack[i], false ) )
+                return legs[m_leg-1]->top();
+        }
     }
-    kDebug(11111) << m_leg;
+
     if (m_redeal > 4)
         return 0;
-    deckClicked(0);
-    return stack[0]->top();
-}
-
-void Spider::deckClicked(Card*)
-{
-    //kDebug(11111) << "deck clicked" << m_redeal;
-    if (m_redeal > 4)
-        return;
 
     unmarkAll();
-    dealRow();
+
+    for (int column = 0; column < 10; column++) {
+        stack[column]->add(redeals[m_redeal]->top(), false);
+
+        // I may put an Ace on a K->2 pile so it could need cleared.
+        if (stack[column]->top()->rank() == Card::Ace)
+            checkPileDeck(stack[column]);
+    }
+    redeals[m_redeal++]->setVisible(false);
+
     takeState();
+    considerGameStarted();
+    if (m_redeal > 4)
+        emit newCardsPossible(false);
+
+    return stack[0]->top();
 }
 
 static class LocalDealerInfo17 : public DealerInfo
 {
 public:
     LocalDealerInfo17() : DealerInfo(I18N_NOOP("Spider"), 17) { addOldId(14); addOldId(15); addOldId(16); }
-    virtual DealerScene *createGame() { return new Spider(); }
+    virtual DealerScene *createGame() const { return new Spider(); }
 } ldi17;
 
 void Spider::mapOldId(int id)
