@@ -19,54 +19,28 @@
 #ifndef VIEW_H
 #define VIEW_H
 
-#include <QGraphicsView>
-
 class DealerScene;
-class QWheelEvent;
+
 class KXmlGuiWindow;
-class QAction;
+
+#include <QtGui/QGraphicsView>
+class QWheelEvent;
 
 class PatienceView: public QGraphicsView
 {
-    friend class DealerScene;
-
     Q_OBJECT
 
 public:
 
-    PatienceView ( KXmlGuiWindow* parent );
+    PatienceView ( KXmlGuiWindow* _window, QWidget* _parent );
     virtual ~PatienceView();
 
     static PatienceView *instance();
 
-    void setViewSize(const QSize &size);
-
-    virtual void setupActions();
-
-    QString anchorName() const;
-    void setAnchorName(const QString &name);
-
-    void setSolverEnabled(bool a);
-    void setAutoDropEnabled(bool a);
-
-    void setGameNumber(long gmn);
-    long gameNumber() const;
-
     void setScene( QGraphicsScene *scene);
     DealerScene  *dscene() const;
 
-    bool wasShown() const { return m_shown; }
-    void setWasShown(bool b) { m_shown = b; }
-
-    KXmlGuiWindow *parent() const;
-
-public slots:
-
-    // restart is pure virtual, so we need something else
-    virtual void startNew();
-    void hint();
-    void slotEnableRedeal(bool);
-    void toggleDemo(bool);
+    KXmlGuiWindow *mainWindow() const;
 
 protected:
 
@@ -75,14 +49,9 @@ protected:
 
 protected:
 
-    QAction *ademo;
-    QAction *ahint, *aredeal, *adrop;
-
-    QString ac;
     static PatienceView *s_instance;
 
-    qreal scaleFactor;
-    bool m_shown;
+    KXmlGuiWindow * m_window;
 };
 
 #endif
