@@ -12,9 +12,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Ffile:///home/kde-devel/playground/games/ksirk/ksirk/GameLogic/onu.cpp
-file:///home/kde-devel/playground/games/ksirk/ksirk/GameLogic/onu.h
-ranklin Street, Fifth Floor, Boston, MA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA
 */
 
@@ -75,7 +73,7 @@ void KGameWindow::mouseMoveEvent ( QMouseEvent * event )
   QPointF mousePosition;
   Country *mouseLocalisation;
 
-  if (m_frame == 0)
+  if (m_frame == 0 || m_reinitializingGame)
   {
     return;
   }
@@ -103,7 +101,7 @@ void KGameWindow::mouseMoveEvent ( QMouseEvent * event )
       const Player* player = mouseLocalisation-> owner();
       if (player)
       {
-        status1Text = i18n("%1 belongs to %2. %3 armies.",i18n(countryName.toUtf8().data()),player->name(),mouseLocalisation->nbArmies());
+        status1Text = i18np("%2 belongs to %3. 1 army.","%2 belongs to %3. %1 armies.",mouseLocalisation->nbArmies(),i18n(countryName.toUtf8().data()),player->name());
       }
 
       statusBar()-> changeItem(status1Text, ID_STATUS_MSG);
@@ -132,6 +130,11 @@ void KGameWindow::mouseMoveEvent ( QMouseEvent * event )
           && (mousePos.x() >= 0) && (mousePos.x() <= m_frame-> viewport()->width()))
     )
   )
+  // safety check for NULL arrow pointers, can happen with Qt 4.5
+  if (m_uparrow == 0 || m_downarrow == 0 || m_leftarrow == 0 || m_rightarrow == 0)
+  {
+    return;
+  }
   if (currentWidget() != 0)
   {
     m_timer.start(200);
@@ -380,69 +383,18 @@ bool KGameWindow::queryExit()
   return true;
 }
 
-void KGameWindow::slotKey1()
-{
-  if (    ( isMyState(GameLogic::GameAutomaton::WAITDEFENSE)  ) 
-       && ( m_secondCountry ) 
-       && ( m_secondCountry->owner())
-       && ( !m_secondCountry->owner()->isAI() ) 
-       && ( !m_secondCountry->owner()->isVirtual())
-     ) 
-  {
-    slotDefense1();
-  }
-  else if (    ( isMyState(GameLogic::GameAutomaton::WAIT)  ) 
-       && ( !currentPlayer()->isAI() ) 
-       && ( !currentPlayer()->isVirtual())
-       )
-  {
-    slotAttack1();
-  } 
-}
-
-void KGameWindow::slotKey2()
-{
-  if (    ( isMyState(GameLogic::GameAutomaton::WAITDEFENSE)  ) 
-       && ( m_secondCountry ) 
-       && ( m_secondCountry->owner())
-       && ( !m_secondCountry->owner()->isAI() ) 
-       && ( !m_secondCountry->owner()->isVirtual())
-     ) 
-  {
-    slotDefense2();
-  }
-  else if (    ( isMyState(GameLogic::GameAutomaton::WAIT)  ) 
-       && ( !currentPlayer()->isAI() ) 
-       && ( !currentPlayer()->isVirtual())
-       )
-  {
-    slotAttack2();
-  } 
-}
-
-void KGameWindow::slotKey3()
-{
-  if (    ( isMyState(GameLogic::GameAutomaton::WAIT)  ) 
-       && ( !currentPlayer()->isAI() ) 
-       && ( !currentPlayer()->isVirtual())
-       )
-  {
-    slotAttack3();
-  } 
-}
-
 void KGameWindow::slotArena(bool isCheck)
 {
-	if (isCheck)
-	{
-		ARENA = true;
-		kDebug() << "*******Arena On******" << ARENA;
-	}
-	else
-	{
-		ARENA = false;
-		kDebug() << "*******Arena Off******" << ARENA;
-	}
+  if (isCheck)
+  {
+    m_useArena = true;
+    kDebug() << "*******Arena On******" << m_useArena;
+  }
+  else
+  {
+    m_useArena = false;
+    kDebug() << "*******Arena Off******" << m_useArena;
+  }
 }
 
 void KGameWindow::slotJabberGame()
@@ -513,8 +465,8 @@ void KGameWindow::slotSaveGame()
       QString fileName = KFileDialog::getSaveFileName (KUrl(), "*.xml", this, i18n("KsirK - Save Game"));
       if ( QFile::exists(fileName)
           && (KMessageBox::questionYesNo (this,
-                i18n("%1 exists.\nDo you really want to overwrite it ?",fileName),
-                i18n("Overwrite file ?")) == KMessageBox::No) )
+                i18n("%1 exists.\nDo you really want to overwrite it?",fileName),
+                i18n("Overwrite file?")) == KMessageBox::No) )
       {
         m_message->setMessageTimeout(3000);
         m_message->showMessage(i18n("Saving canceled"), KGamePopupItem::TopLeft,
@@ -831,62 +783,6 @@ void KGameWindow::slotRemoveMessage()
   }
 }
 
-void KGameWindow::slideMove(int v)
-{
-  kDebug() << v;
-  m_nbLArmy = m_nbLArmy-(v-m_currentSlideValue);
-  m_nbRArmy = m_nbRArmy+(v-m_currentSlideValue);
-  m_nbLArmies->setText(QString::number(m_nbLArmy));
-  m_nbRArmies->setText(QString::number(m_nbRArmy));
-  m_wSlide->update();
-  m_currentSlideValue = v;
-  
-  m_automaton->currentPlayerPlayed(true);
-}
-
-void KGameWindow::slideReleased()
-{
-  kDebug() << "do nothing";
-}
-
-void KGameWindow::slideClose()
-{
-  kDebug();
-  m_automaton->currentPlayerPlayed(true);
-  
-  int units=m_invadeSlide->value();
-  
-  int reste10 = units%10;
-  int reste5;
-  for(int i=0;i<(units-reste10)/10;i++)
-  {
-    QByteArray buffer;
-    QDataStream stream(&buffer, QIODevice::WriteOnly);
-    stream << quint32(10);
-    automaton()->sendMessage(buffer,Invade);
-  }
-  
-  reste5 = reste10%5;
-  for(int i=0;i<(reste10-reste5)/5;i++)
-  {
-    QByteArray buffer;
-    QDataStream stream(&buffer, QIODevice::WriteOnly);
-    stream << quint32(5);
-    automaton()->sendMessage(buffer,Invade);
-  }
-  for(int i=0;i<reste5;i++)
-  {
-    QByteArray buffer;
-    QDataStream stream(&buffer, QIODevice::WriteOnly);
-    stream << quint32(1);
-    automaton()->sendMessage(buffer,Invade);
-  }
-  m_wSlide->close();
-  
-  QByteArray buffer;
-  automaton()->sendMessage(buffer,InvasionFinished);
-}
-
 void KGameWindow::slotContextualHelp()
 {
   kDebug();
@@ -929,7 +825,7 @@ void KGameWindow::slotDefAuto()
     m_automaton->gameEvent("actionDefense1", point);
   else
     m_automaton->gameEvent("actionDefense2", point);
-  dial->close();
+  m_defenseDialog->close();
 }
 
 void KGameWindow::slotWindowDef1()
@@ -937,7 +833,7 @@ void KGameWindow::slotWindowDef1()
   QPoint point;
   kDebug()<<"Recept signal defense with one army";
   m_automaton->gameEvent("actionDefense1", point);
-  dial->close();
+  m_defenseDialog->close();
 }
 
 void KGameWindow::slotWindowDef2()
@@ -945,13 +841,14 @@ void KGameWindow::slotWindowDef2()
   QPoint point;
   kDebug()<<"Recept signal defense with two army";
   m_automaton->gameEvent("actionDefense2", point);
-  dial->close();
+  m_defenseDialog->close();
 }
 
 void KGameWindow::slotNewGameOK(unsigned int nbPlayers, const QString& skin, unsigned int nbNetworkPlayers, bool useGoals)
 {
   kDebug() << nbPlayers << skin << nbNetworkPlayers << useGoals;
   m_automaton->setGameStatus(KGame::End);
+  m_reinitializingGame = true;
   m_automaton->removeAllPlayers();
 
   showMap();
@@ -961,6 +858,7 @@ void KGameWindow::slotNewGameOK(unsigned int nbPlayers, const QString& skin, uns
   m_automaton->savedState(GameLogic::GameAutomaton::INVALID);
   m_automaton->setNetworkPlayersNumber(m_automaton->networkGameType()==GameAutomaton::None?0:nbNetworkPlayers);
   m_automaton->finishSetupPlayersNumberAndSkin(skin, m_automaton->networkGameType(), nbPlayers);
+  m_reinitializingGame = false;
 
   if (m_automaton->networkGameType()==GameAutomaton::Jabber && m_jabberClient && m_jabberClient->isConnected())
   {
@@ -1124,9 +1022,9 @@ void KGameWindow::slotGroupChatJoined (const XMPP::Jid & jid)
   /*    <message type="chat" to="kleag@localhost" id="aabca" >
   <body>hello</body>
   </message>*/
-  XMPP::Message message(m_groupchatRoom+"@"+m_groupchatHost);
+  XMPP::Message message(m_groupchatRoom+'@'+m_groupchatHost);
   message.setType("groupchat");
-  message.setId(QUuid::createUuid().toString().remove("{").remove("}").remove("-"));
+  message.setId(QUuid::createUuid().toString().remove('{').remove('}').remove('-'));
   message.setBody("Hello, I'm a KsirK Game");
   m_jabberClient->sendMessage(message);
 
@@ -1146,7 +1044,7 @@ void KGameWindow::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::Stat
   {
     XMPP::Message message(jid);
     message.setType("ksirkgame");
-    message.setId(QUuid::createUuid().toString().remove("{").remove("}").remove("-"));
+    message.setId(QUuid::createUuid().toString().remove('{').remove('}').remove('-'));
     message.setBody(QString("Hello, ")+jid.full());
     m_jabberClient->sendMessage(message);
     m_presents.insert(jid.full());
@@ -1175,7 +1073,7 @@ void KGameWindow::slotGroupChatError (const XMPP::Jid &jid, int error, const QSt
     case JabberClient::NicknameConflict:
     {
       bool ok;
-      QString nickname = KInputDialog::getText(i18n("Error trying to join %1 : nickname %2 is already in use", jid.node(), jid.resource()), i18n("Provide your nickname"), QString(), &ok);
+      QString nickname = KInputDialog::getText(i18n("Error trying to join %1: nickname %2 is already in use", jid.node(), jid.resource()), i18n("Provide your nickname"), QString(), &ok);
       if (ok)
       {
         m_jabberClient->joinGroupChat(jid.domain(), jid.node(), nickname);
